{
  pkgs,
  lib,
  ...
}: {
  home.username = "blue";
  home.homeDirectory = "/home/blue";

  imports = [
    ./hyprland.nix
    ./waybar.nix
    ./swaync.nix
    ./hyprlock.nix
    ./zsh.nix
    ./eza.nix
    ./nvf.nix
    ./nextcloud.nix
    ./git.nix
    ./stylix.nix
    ./direnv.nix
    ./firefox.nix
    ./zellij.nix
    ./obs-studio.nix
  ];

  home.stateVersion = "24.05";

  services.gnome-keyring.enable = true; # used for nextcloud-client

  # General use home packages that dont require a separate module
  home.packages = with pkgs; [
    grimblast # Screenshot tool
    powerline-fonts # Fonts
    nix-output-monitor # Provides a dependency graph for nix builds
    bitwarden-desktop # Integrates with bitwarden extension
    wofi # Wayland app launcher
    nvtopPackages.amd # GPU monitor, more detailed than BTOP-rocm
    signal-desktop # Signal messenger client
    nautilus # File manager (move to option maybe)
    element-desktop # Matrix client
    stable.jetbrains.idea-community # IDE
    telegram-desktop # Telegram messenger client
    pavucontrol # Useful audio control GUI
    stable.prismlauncher # Minecraft launcher
    virt-manager # QEMU manager
    bat # cat but with syntax highlighting
    bc # terminal calculator
    wget # download files
    vesktop # discord client
    thunderbird # email client
    fastfetch # silly specs display
    ungoogled-chromium # useful when a website breaks in firefox
    qbittorrent # torrent client
    zip # lets you zip files
    unzip # lets you unzip files
    vlc # media player
    vial # gui for qmk stuff
    qmk # qmk configurator
    wl-clipboard # command-line copy/paste
    lutris # game launcher
    tenacity # small DAW
    davinci-resolve # video editor
    libreoffice # office suite
    nixfmt-rfc-style # nix code formatter

    # Audio Plugins
    calf
    zam-plugins
    lsp-plugins # not language servers, its an audio thing trust me

    ardour # DAW
    gimp3 # GNU Image Manipulation Program, pretty self explanatory
    
    networkmanagerapplet # Tray icon for managing networking
    blueman # Tray icon for managing bluetooth
  ];
  services.flatpak.packages = [
    "io.mrarm.mcpelauncher" # Minecraft bedrock edition launcher
  ];

  home.sessionVariables = {
    DEFAULT_BROWSER = "${lib.getExe pkgs.floorp}";
    # Allow XWayland apps to not be weird after turning off xwayland scaling in hyprland.conf
    GDK_SCALE = 1;
    XCURSOR_SIZE = 24;
    # Set default editor
    EDITOR = "nvim";
    NIXOS_OZONE_WL = 1;
    LD_LIBRARY_PATH = "${pkgs.libGL}/lib:${pkgs.gtk3}/lib:${pkgs.glib.out}/lib:${pkgs.xorg.libXtst}/lib";
  };

  # Let Home Manager install and manage itself.
  programs.home-manager.enable = true;

  programs.tmux.enable = true;
  programs.zoxide = {
    enable = true;
    enableZshIntegration = true;
  };

  programs.btop.enable = true;
  programs.btop.package = pkgs.stable.btop-rocm;

  # Add support for bluetooth headset media controls
  services.mpris-proxy.enable = true;

  programs.alacritty = {
    enable = true;
    package = pkgs.alacritty;
    settings = {
      window.dimensions = {
        lines = 3;
        columns = 200;
      };
    };
  };
}
